==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24MouseInputHandler.h <==
// public class javax.swing.plaf.basic.BasicDesktopIconUI$MouseInputHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 897a6261c68abb83 javax_swing_event_MouseInputAdapter
// @dep_class 7d2a6bb8924dc893 javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler

// header file dependencies
// @dep_header javax_swing_event_MouseInputAdapter

#include "javax/swing/event/MouseInputAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JDesktopPane$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$_init$908b6c65f42513bc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$moveAndRepaint$a107c0ea72d2b541(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_JComponent$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$moveAndRepaint$a107c0ea72d2b541;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*moveAndRepaint$a107c0ea72d2b541)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_JComponent$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_MouseInputAdapter$vmethods	javax_swing_event_MouseInputAdapter;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs {
	struct _jc_javax_swing_JDesktopPane$object	*pane;
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
    _jc_javax_swing_event_MouseInputAdapter$sub_refs	javax_swing_event_MouseInputAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs {
	jint	xOffset;
	jint	yOffset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_MouseInputAdapter$sub_nonrefs	javax_swing_event_MouseInputAdapter;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicDesktopIconUI__24MouseInputHandler.h <==
// public class javax.swing.plaf.basic.BasicDesktopIconUI$MouseInputHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 897a6261c68abb83 javax_swing_event_MouseInputAdapter
// @dep_class 7d2a6bb8924dc893 javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler

// header file dependencies
// @dep_header javax_swing_event_MouseInputAdapter

#include "javax/swing/event/MouseInputAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_JDesktopPane$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$_init$908b6c65f42513bc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseDragged$3079e58fafa0fefe(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseMoved$9e3a895f548fc637(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mousePressed$0e61f2afd4a13bb2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$mouseReleased$47ad6ad312932c8e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method$moveAndRepaint$a107c0ea72d2b541(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_JComponent$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseDragged$3079e58fafa0fefe;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseMoved$9e3a895f548fc637;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mousePressed$0e61f2afd4a13bb2;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$mouseReleased$47ad6ad312932c8e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$method_info$moveAndRepaint$a107c0ea72d2b541;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods {
	void	(*mouseDragged$3079e58fafa0fefe)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseMoved$9e3a895f548fc637)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mousePressed$0e61f2afd4a13bb2)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*mouseReleased$47ad6ad312932c8e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*moveAndRepaint$a107c0ea72d2b541)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object *, struct _jc_javax_swing_JComponent$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_event_MouseInputAdapter$vmethods	javax_swing_event_MouseInputAdapter;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vmethods	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs {
	struct _jc_javax_swing_JDesktopPane$object	*pane;
	struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_refs	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
    _jc_javax_swing_event_MouseInputAdapter$sub_refs	javax_swing_event_MouseInputAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs {
	jint	xOffset;
	jint	yOffset;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_event_MouseInputAdapter$sub_nonrefs	javax_swing_event_MouseInputAdapter;
    _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$object {
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$vtype _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopIconUI__24MouseInputHandler_H_ */
